#
# spec file for package supervisor
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           supervisor
Version:        3.1.3
Release:        1.10
Url:            http://supervisord.org/
Summary:        A system for controlling process state under UNIX
License:        SUSE-Repoze
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/s/supervisor/supervisor-%{version}.tar.gz
Source1:        supervisord.init
Source2:        supervisord.conf
Source3:        supervisord.service
Source4:        supervisord.tmpfile
Patch:          interpreter.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-medusa
BuildRequires:  python-meld3
BuildRequires:  python-setuptools
%if 0%{?suse_version} >= 1230
BuildRequires:  systemd
%{?systemd_requires}
%else
Requires(pre): %insserv_prereq
%endif
Requires:       python-meld3
Requires:       python-setuptools
Requires:       python-xml
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Supervisor is a client/server system that allows its users to
control a number of processes on UNIX-like operating systems.

%prep
%setup -q -n supervisor-%{version}
%patch

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%{__install} -d %{buildroot}%{_sbindir}
%{__install} -d %{buildroot}%{_sysconfdir}
%{__install} -d %{buildroot}%{_sysconfdir}/supervisord.d
%if 0%{?suse_version} >= 1230
%{__install} -D -m 755 %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/supervisord.conf
%{__install} -D -m 755 %{SOURCE3} %{buildroot}%{_unitdir}/supervisord.service
%{__ln_s} -f /sbin/service %{buildroot}%{_sbindir}/rcsupervisord
%else
%{__install} -D -m 755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/supervisord
%{__ln_s} -f %{_sysconfdir}/init.d/supervisord %{buildroot}%{_sbindir}/rcsupervisord
# Socket and PID dir
%{__install} -d -m 700 %{buildroot}%{_localstatedir}/run/supervisord/
%endif
# Logs dir.
%{__install} -d -m 750 %{buildroot}%{_localstatedir}/log/supervisord/
%{__install} -m 660 %{S:2} %{buildroot}%{_sysconfdir}/

%if 0%{?suse_version} >= 1230
%pre
%service_add_pre supervisord.service
%endif

%post
%if 0%{?suse_version} >= 1230
%service_add_post supervisord.service
%else
%fillup_and_insserv supervisord
%endif

%preun
%if 0%{?suse_version} >= 1230
%service_del_preun supervisord.service
%else
%stop_on_removal supervisord
%endif

%postun
%if 0%{?suse_version} >= 1230
%service_del_postun supervisord.service
%else
%insserv_cleanup
%restart_on_update supervisord
%endif

%files
%defattr(-,root,root,-)
%doc README.rst CHANGES.txt TODO.txt LICENSES.txt COPYRIGHT.txt
%{python_sitelib}/*
%{_bindir}/echo_supervisord_conf
%{_bindir}/pidproxy
%{_bindir}/supervisorctl
%{_bindir}/supervisord
%{_sbindir}/rcsupervisord
%if 0%{?suse_version} >= 1230
%{_prefix}/lib/tmpfiles.d/supervisord.conf
%{_unitdir}/supervisord.service
%else
%{_sysconfdir}/init.d/supervisord
%dir %attr(700,root,root)%{_localstatedir}/run/supervisord
%endif
%config(noreplace) %{_sysconfdir}/supervisord.conf
%dir %{_sysconfdir}/supervisord.d
%dir %attr(750,root,root)%{_localstatedir}/log/supervisord

%changelog
* Thu Apr 16 2015 hpj@urpla.net
- Update to version 3.1.3
  - 3.1.3 (2014-10-28)
  - Fixed an XML-RPC bug where the ElementTree-based parser handled strings
    like ``<value><string>hello</string></value>`` but not strings like
    ``<value>hello</value>``, which are valid in the XML-RPC spec.  This
    fixes compatibility with the Apache XML-RPC client for Java and
    possibly other clients.
  - 3.1.2 (2014-09-07)
  - Fixed a bug where ``tail group:*`` in ``supervisorctl`` would show a 500
    Internal Server Error rather than a BAD_NAME fault.
  - Fixed a bug where the web interface would show a 500 Internal Server Error
    instead of an error message for some process start faults.
  - Removed medusa files not used by Supervisor.
  3.1.1 (2014-08-11)
  - Fixed a bug where ``supervisorctl tail -f name`` output would stop if log
    rotation occurred while tailing.
  - Prevent a crash when a greater number file descriptors were attempted to be
    opened than permitted by the environment when starting a bunch of programs.
    Now, instead a spawn error is logged.
  - Compute "channel delay" properly, fixing symptoms where a supervisorctl start
    command would hang for a very long time when a process (or many processes)
    are spewing to their stdout or stderr.  See comments attached to
    https://github.com/Supervisor/supervisor/pull/263 .
  - Added docs/conf.py, docs/Makefile, and supervisor/scripts/*.py to
    the release package.
  - 3.1.0 (2014-07-29)
  - The output of the ``start``, ``stop``, ``restart``, and ``clear`` commands
    in ``supervisorctl`` has been changed to be consistent with the ``status``
    command.  Previously, the ``status`` command would show a process like
    ``foo:foo_01`` but starting that process would show ``foo_01: started``
    (note the group prefix ``foo:`` was missing).  Now, starting the process
    will show ``foo:foo_01: started``.  Suggested by Chris Wood.
  - The ``status`` command in ``supervisorctl`` now supports group name
    syntax: ``status group:*``.
  - The process column in the table output by the ``status`` command in
    ``supervisorctl`` now expands to fit the widest name.
  - The ``update`` command in ``supervisorctl`` now accepts optional group
    names.  When group names are specified, only those groups will be
    updated.  Patch by Gary M. Josack.
  - Tab completion in ``supervisorctl`` has been improved and now works for
    more cases.  Thanks to Mathieu Longtin and Marc Abramowitz for the patches.
  - Attempting to start or stop a process group in ``supervisorctl`` with the
    ``group:*`` syntax will now show the same error message as the ``process``
    syntax if the name does not exist.  Previously, it would show a Python
    exception.  Patch by George Ang.
  - Added new ``PROCESS_GROUP_ADDED`` and ``PROCESS_GROUP_REMOVED`` events.
    These events are fired when process groups are added or removed from
    Supervisor's runtime configuration when using the ``add`` and ``remove``
    commands in ``supervisorctl``.  Patch by Brent Tubbs.
  - Stopping a process in the backoff state now changes it to the stopped
    state.  Previously, an attempt to stop a process in backoff would be
    ignored.  Patch by Pascal Varet.
  - The ``directory`` option is now expanded separately for each process in
    a homogeneous process group.  This allows each process to have its own
    working directory.  Patch by Perttu Ranta-aho.
  - Removed ``setuptools`` from the ``requires`` list in ``setup.py`` because
    it caused installation issues on some systems.
  - Fixed a bug in Medusa where the HTTP Basic authorizer would cause an
    exception if the password contained a colon.  Thanks to Thomas Guttler
    for reporting this issue.
  - Fixed an XML-RPC bug where calling supervisor.clearProcessLogs() with a
    name like ``group:*`` would cause a 500 Internal Server Error rather than
    returning a BAD_NAME fault.
  - Fixed a hang that could occur in ``supervisord`` if log rotation is used
    and an outside program deletes an active log file.  Patch by Magnus Lycka.
  - A warning is now logged if a glob pattern in an ``[include]`` section does
    not match any files.  Patch by Daniel Hahler.
- regenerated sample config (but kept volatile dir instead of /tmp)
- add %%pre service, as hinted by rpmlint
- mv tmpfile conf to /usr/lib/tmpfiles.d/
* Tue Apr 14 2015 hpj@urpla.net
- deal with nowadays volatile /var/run directory
- create and include /etc/supervisord.d
- run supervisord with recommended -c option
* Sun Dec 22 2013 matthew@mmckeen.net
- Add python-xml as a depedency, it provides the libraries that used
  to be a part of python-elementtree
* Sun Dec 22 2013 p.drouand@gmail.com
- Remove dependency on python-elementtree; none package provides it
* Sat Nov  9 2013 p.drouand@gmail.com
- Update to version 3.0 final
  + Parsing the config file will now fail with an error message if a
    process or group name contains characters that are not compatible
    with the eventlistener protocol.
  + Fixed a bug where the tail -f command in supervisorctl would fail if
    the combined length of the username and password was over 56 characters.
  + Reading the config file now gives a separate error message when the
    config file exists but can't be read. Previously, any error reading the
    file would be reported as "could not find config file".
  + Fixed an XML-RPC bug where array elements after the first would be
    ignored when using the ElementTree-based XML parser.
  + Fixed the usage message output by supervisorctl to show the correct
    default config file path.
- Add systemd support for openSUSE >= 12.3
- Fix sysvinit support
  + add missing %%post section
  + add missing Requires(pre): insserv_prereq
  + use correct init script name in %%postun/preun
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Sep  9 2013 fcastelli@suse.com
- Fixed runtime requirement of python-elementtree. ElementTree has been
  merged into python 2.5. Hence there's not need to require it for recent
  versions of SLE/openSUSE.
* Wed Dec  7 2011 alexandre@exatati.com.br
- Update to 3.0a12:
  - Released to replace a broken 3.0a11 package where non-Python files
    were not included in the package.
- Aditional changes from 3.0a11:
  - The pid command in supervisorctl can now be used to retrieve the PIDs
    of child processes. See help pid. Patch by Gregory Wisniewski.
  - Added a new host_node_name expansion that will be expanded to the
    value returned by Python's platform.node (see
    http://docs.python.org/library/platform.html#platform.node). Patch by
    Joseph Kondel.
  - Fixed a bug in the web interface where pages over 64K would be
    truncated. Thanks to Drew Perttula and Timothy Jones for reporting this.
  - Renamed README.txt to README.rst so GitHub renders the file as
    ReStructuredText.
  - The XML-RPC server is now compatible with clients that do not send
    empty <params> when there are no parameters for the method call.
    Thanks to Johannes Becker for reporting this.
  - Fixed supervisorctl --help output to show the correct program name.
  - The behavior of the configuration options minfds and minprocs has
    changed. Previously, if a hard limit was less than minfds or minprocs,
    supervisord would unconditionally abort with an error. Now, supervisord
    will attempt to raise the hard limit. This may succeed if supervisord
    is run as root, otherwise the error is printed as before. Patch by
    Benoit Sigoure.
  - Add a boolean program option killasgroup, defaulting to false, if
    true when resorting to send SIGKILL to stop/terminate the process
    send it to its whole process group instead to take care of possible
    children as well and not leave them behind. Patch by Samuele Pedroni.
  - Environment variables may now be used in the configuration file for
    options that support string expansion. Patch by GitHub user "silver-".
  - Fixed a race condition where supervisord might not act on a signal
    sent to it. Thanks to Adar Dembo for reporting the issue and supplying
    the initial patch.
  - Updated the output of echo_supervisord_conf to fix typos and
    improve comments. Thanks to Jens Rantil for noticing these.
- Removed docdir.patch, no more needed.
* Thu Apr 21 2011 alexandre@exatati.com.br
- Add %%preun and %%postun sections in spec file.
* Thu Apr 21 2011 alexandre@exatati.com.br
- Update to 3.0a10:
  - Fixed the stylesheet of the web interface so the footer line won't overlap
    a long process list.  Thanks to Derek DeVries for the patch.
  - Allow rpc interface plugins to register new events types.
  - Bug fix for FCGI sockets not getting cleaned up when the ``reload`` command
    is issued from supervisorctl.  Also, the default behavior has changed for
    FCGI sockets.  They are new closed whenever the number ofrunning processes
    in a group hits zero.  Previously, the sockets were kept open unless a
    group-level stop command was issued.
  - Better error message when HTTP server cannot reverse-resolve a hostname to
    an IP address.  Previous behavior: show a socket error.  Current behavior:
    spit out a suggestion to stdout.
  - Environment variables set via ``environment=`` value within
    ``[supervisord]`` section had no effect.  Thanks to Wyatt Baldwin
  for a patch.
  - Fix bug where stopping process would cause process output that happened
    after the stop request was issued to be lost.  See
    https://github.com/Supervisor/supervisor/issues/11.
  - Moved 2.X change log entries into ``HISTORY.txt``.
  - Converted ``CHANGES.txt`` and ``README.txt`` into proper ReStructuredText
    and included them in the ``long_description`` in ``setup.py``.
  - Added a tox.ini to the package (run via ``tox`` in the package dir).  Tests
    supervisor on multiple Python versions.
- Replace python-setuptools by python-distribute in spec file.
* Wed Sep 22 2010 alexandre@exatati.com.br
- Update to 3.0a9;
- Created example config file.
* Mon Jun 21 2010 alexandre@exatati.com.br
- Initial package (3.0a8) for openSUSE.
